<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  カテゴリ名称の取得
 *
 *  @access public
 *  @param  integer $category_id        カテゴリID
 */
function db_get_category_name($category_id)
{
    $sql = 'SELECT category_name' .
            ' FROM pbb_categories' .
            ' WHERE category_id = ?';
    $params = array(
        intval($category_id)
    );
    return pocket_db_getOne($sql, $params);
}

/**
 *  カテゴリ情報の取得
 *
 *  @access public
 *  @param  integer $category_id        カテゴリID
 */
function db_get_category($category_id)
{
    $sql = 'SELECT category_id, parent_id, category_name, outline, sort_order, r_datetime' .
            ' FROM pbb_categories' .
            ' WHERE category_id = ?';
    $params = array(
        intval($category_id)
    );
    return pocket_db_getRow($sql, $params);
}

/**
 *  カテゴリ一覧情報の取得（絞込み無）
 *
 *  @access public
 */
function db_get_categories4admin()
{
    $sql = 'SELECT category_id, parent_id, category_name, outline, sort_order, r_datetime' .
            ' FROM pbb_categories' .
            ' ORDER BY parent_id, sort_order';
    return pocket_db_getAll($sql);
}

/**
 *  カテゴリ一覧情報の取得（絞込み有）
 *
 *  @access public
 *  @param  integer $category_id        カテゴリID
 */
function db_get_categories4admin_condition($category_id)
{
    $sql = 'SELECT category_id, parent_id, category_name, outline, sort_order, r_datetime' .
            ' FROM pbb_categories' .
            ' WHERE category_id = ? OR parent_id = ?' .
            ' ORDER BY parent_id, sort_order';
    $params = array(
        intval($category_id),
        intval($category_id)
    );

    return pocket_db_getAll($sql, $params);
}

/**
 *  カテゴリの子ノード情報の取得
 *
 *  @access public
 */
function db_get_categories4children($category_id)
{
    $sql = 'SELECT category_id, category_name, outline, sort_order, r_datetime' .
            ' FROM pbb_categories' .
            ' WHERE parent_id = ?' .
            ' ORDER BY sort_order';
    $params = array(
        intval($category_id)
    );
    return pocket_db_getAll($sql, $params);
}

/**
 *  カテゴリ情報の登録
 *
 *  @access public
 *  @param  string  $category_name      カテゴリ名
 *  @param  string  $outline            概要
 *  @param  integer $parent_id          上位ID
 *  @param  integer $sort_order         表示順
 */
function db_insert_category($category_name, $outline, $parent_id, $sort_order)
{
    $data = array(
        'category_name' => $category_name,
        'outline' => $outline,
        'parent_id' => $parent_id,
        'sort_order' => $sort_order,
        'r_datetime' => pocket_db_getNow()
    );
    return pocket_db_insert('pbb_categories', $data, 'pbb_categories_category_id_seq');
}

/**
 *  カテゴリ情報の更新
 *
 *  @access public
 *  @param  integer $category_id        ID
 *  @param  string  $category_name      カテゴリ名
 *  @param  string  $outline            概要
 *  @param  integer $parent_id          上位ID
 *  @param  integer $sort_order         表示順
 */
function db_update_category($category_id, $category_name, $outline, $parent_id, $sort_order)
{
    $data = array(
        'category_name' => $category_name,
        'outline' => $outline,
        'parent_id' => $parent_id,
        'sort_order' => $sort_order,
        'r_datetime' => pocket_db_getNow()
    );
    $where = array(
        'category_id' => intval($category_id)
    );
    return pocket_db_update('pbb_categories', $data, $where);
}

/**
 *  カテゴリ情報の削除
 *
 *  @access public
 *  @param  integer $category_id            ID
 */
function db_delete_category($category_id)
{
    if (!db_update_topics_category4default($category_id)) {return false;}
    return pocket_db_delete('pbb_categories', 'category_id', $category_id);
}

?>
