<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  指定コメント情報の取得
 *
 *  @access public
 *  @param  integer $post_comment_id    コメントID
 */
function db_get_topic_comment4delete($topic_comment_id)
{
    $sql = 'SELECT tc.topic_comment_id, tc.topic_id, t.category_id, tc.author_name, tc.author_email, tc.comment, tc.r_datetime' .
            ' FROM pbb_topic_comments AS tc' .
            ' LEFT JOIN pbb_topics AS t' .
                ' ON tc.topic_id = t.topic_id' .
            ' WHERE tc.topic_comment_id = ?';
    $params = array(
        intval($topic_comment_id)
    );
    return pocket_db_getRow($sql, $params);
}

/**
 *  指定トピックのコメント情報の取得
 *
 *  @access public
 *  @param  integer $topic_id            トピックID
 */
function db_get_topic_comments4topic_comment($topic_id)
{
    $sql = 'SELECT topic_comment_id, topic_id, author_name, author_email, comment, r_datetime' .
            ' FROM pbb_topic_comments' .
            ' WHERE topic_id = ?' .
            ' ORDER BY r_datetime';
    $params = array(
        intval($topic_id)
    );
    return pocket_db_getAll($sql, $params);
}

/**
 *  最新のコメント一覧情報の取得
 *
 *  @access public
 *  @param  integer $page               ページ番号
 *  @param  integer $page_size          ページサイズ
 */
function db_get_topic_comments4latest_comment_list($page = 1, $page_size = 5)
{
    $sql = 'SELECT tc.topic_comment_id, tc.topic_id, tc.comment, tc.author_name, tc.r_datetime' .
            ' FROM pbb_topic_comments AS tc' .
            ' LEFT JOIN pbb_topics AS t' .
                ' ON tc.topic_id = t.topic_id' .
            ' ORDER BY tc.r_datetime DESC';
    return pocket_db_getAllPage($sql, $page, $page_size);
}

/**
 *  最新のコメント一覧情報（RSS用）の取得
 *
 *  @access public
 *  @param  integer $page_size          ページサイズ
 */
function db_get_topic_comments4latest_comment_rss($page_size = 5)
{
    $sql = 'SELECT tc.topic_comment_id, tc.topic_id, t.subject AS title, tc.comment AS description, tc.author_name, tc.r_datetime' .
            ' FROM pbb_topic_comments AS tc' .
            ' LEFT JOIN pbb_topics AS t' .
                ' ON tc.topic_id = t.topic_id' .
            ' ORDER BY tc.r_datetime DESC';
    return pocket_db_getAllPage($sql, 1, $page_size);
}

/**
 *  未チェックのコメント情報の取得
 *
 *  @access public
 *  @param  integer $page               ページ番号
 *  @param  integer $page_size          ページサイズ
 */
function db_get_topic_comments4unchecked($page = 1, $page_size = 5)
{
    $sql = 'SELECT t.topic_id, t.category_id, ca.category_name, t.subject,' .
            ' tc.topic_comment_id, tc.author_name, tc.author_email, tc.comment, tc.r_datetime' .
            ' FROM pbb_topics AS t' .
            ' LEFT JOIN pbb_topic_comments AS tc' .
                ' ON t.topic_id = tc.topic_id' .
            ' LEFT JOIN pbb_categories AS ca' .
                ' ON t.category_id = ca.category_id' .
            ' WHERE tc.is_checked = ?' .
            ' ORDER BY tc.r_datetime DESC';
    $params = array(
        intval(false)
    );
    return pocket_db_getAllPage($sql, $page, $page_size, $params);
}

/**
 *  未チェックのコメント件数の取得
 *
 *  @access public
 */
function db_get_topic_comments_count4unchecked()
{
    $sql = 'SELECT count(topic_comment_id)' .
            ' FROM pbb_topic_comments' .
            ' WHERE is_checked = ?';
    $params = array(
        intval(false)
    );
    return pocket_db_getOne($sql, $params);
}

/**
 *  コメント情報の登録（コメント削除許可有）
 *
 *  @access public
 *  @param  integer $topic_id           トピックID
 *  @param  integer $is_checked         コメントチェックフラグ
 *  @param  string  $author_name        名前
 *  @param  string  $author_email       メールアドレス
 *  @param  string  $comment            コメント
 *  @param  string  $author_password    暗証番号
*/
function db_insert_topic_comment_allow_yes($topic_id, $is_checked, $author_name, $author_email, $comment, $author_password)
{
    $data = array(
        'topic_id' => $topic_id,
        'is_checked' => intval($is_checked),
        'author_name' => $author_name,
        'author_email' => $author_email,
        'comment' => $comment,
        'author_password' => $author_password,
        'r_datetime' => pocket_db_getNow()
    );
    return pocket_db_insert('pbb_topic_comments', $data, 'pbb_topic_comments_topic_comment_id_seq');
}

/**
 *  コメント情報の登録（コメント削除許可無）
 *
 *  @access public
 *  @param  integer $topic_id           トピックID
 *  @param  integer $is_checked         コメントチェックフラグ
 *  @param  string  $author_name        名前
 *  @param  string  $author_email       メールアドレス
 *  @param  string  $comment            コメント
*/
function db_insert_topic_comment_allow_no($topic_id, $is_checked, $author_name, $author_email, $comment)
{
    $data = array(
        'topic_id' => $topic_id,
        'is_checked' => intval($is_checked),
        'author_name' => $author_name,
        'author_email' => $author_email,
        'comment' => $comment,
        'r_datetime' => pocket_db_getNow()
    );
    return pocket_db_insert('pbb_topic_comments', $data, 'pbb_topic_comments_topic_comment_id_seq');
}

/**
 *  コメント情報の確認（チェック）
 *
 *  @access public
 *  @param  integer $topic_comment_id   コメントID
 */
function db_update_topic_comment4check($topic_comment_id)
{
    $data = array(
        'is_checked' => intval(true)
    );
    $where = array(
        'topic_comment_id' => intval($topic_comment_id)
    );
    return pocket_db_update('pbb_topic_comments', $data, $where);
}

/**
 *  コメント情報の削除
 *
 *  @access public
 *  @param  integer $topic_comment_id    コメントID
 */
function db_delete_topic_comment($topic_comment_id)
{
    return pocket_db_delete('pbb_topic_comments', 'topic_comment_id', $topic_comment_id);
}

/**
 *  パスワード認証
 *
 *  @access public
 *  @param  integer $user_id            トピックコメントID
 *  @param  string  $password           パスワード
 */
function db_auth_topic_comments4author_password($topic_comment_id, $author_password)
{
    $sql = 'SELECT topic_comment_id' .
            ' FROM pbb_topic_comments' .
            ' WHERE topic_comment_id = ?' .
            ' AND author_password = ?';
    $params = array(
        intval($topic_comment_id),
        $author_password
    );
    return (bool)pocket_db_getOne($sql, $params);
}
?>
