<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  パスワード再発行処理用のActionクラス
 *
 *  @author     Shogo Minami
 *  @access     public
 *  @package    PocketBBS.pc.do
 */
class passwordReissueUpdateAction extends Pocket_Bbs_Action
{
    /**
     *  アクション実行
     *
     *  @access public
     *  @param  object  $controller         コントローラ
     *  @param  object  $request            リクエスト情報
     *  @return string  success,error
     */
    function execute(&$controller, &$request)
    {
        // リクエスト情報の取得
        $id    = $request['id'];
        $email = $request['email'];

        // ユーザIDの取得
        $user_id = db_get_user_id($id);

        // ユーザ情報の取得
        $user_profile = db_get_user($user_id);

        // パスワードの自動生成
        $new_password = pocket_creatPassword();

        // パスワードの更新
        db_update_userPassword($user_id, md5($new_password));

        // タイトル設定
        $subject = '【 ' . BBS_NAME . ' 】パスワード再発行のお知らせ';

        // 本文設定
        $bbs_name = BBS_NAME;
        $url = pocket_getSiteUrl();
        $body = <<<EOD
{$user_profile['nickname']} さん、こんにちは。
$bbs_name からのお知らせです。

パスワードを再発行いたしました。

メールアドレス：$email
パスワード：$new_password

なお、パスワードの変更は、「パスワード変更」画面から行ってください。

$bbs_name のログインページ
$url

今後とも、ぜひ、$bbs_name をご活用ください。
EOD;

        // メール送信
        $mailObject = new Pocket_Mail();
        $mailObject->send($email, $email, $subject, $body);

        // セッション情報の破棄
        $_SESSION = array();
        // セッションの破棄
        session_destroy();

        // リダイレクト
        pocket_redirect('tologin.view', array('msg' => 'パスワード再発行のメールを送信しました。'));
    }

    /**
     *  リクエスト検証
     *
     *  @access public
     *  @param  object  $validator          バリデータ
     *  @param  object  $request            リクエスト情報
     */
    function validate(&$validator, &$request)
    {
        // リクエスト情報の取得
        $id    = $request['id'];
        $email = $request['email'];

        // エラー表示用のAction名称の設定
        $this->viewAction = 'passwordReissue';

        // 検証
        $validator->validate('id'   , 'ID'    , $id   , 'string', true);
        $validator->validate('email', 'E-Mail', $email, 'email' , true);

        // ユーザIDの取得
        $user_id = db_get_user_id($id);

        // ID、メールアドレスの認証
        if (!db_auth_user4email($user_id, pocket_encrypt($email, POCKET_BBS_ENCRYPT_KEY)))
        {
            $validator->addErrors('id', 'ユーザ認証に失敗しました。');
        }

        // 有効チェック
        if (!$validator->isValid())
        {
            // エラーメッセージをクリア
            $validator->clearErrors();
            $validator->addErrors('id', 'ユーザ認証に失敗しました。');
        }
    }
}

?>
